@@ -21,8 +21,10 @@ class StateCodeEnum(str, Enum):
     hr = "hr"  # Haryana
     hp = "hp"  # Himachal Pradesh
     jh = "jh"  # Jharkhand
+    jk = "jk"  # Jammu and Kashmir
     ka = "ka"  # Karnataka
     kl = "kl"  # Kerala
+    la = "la"  # Ladakh
     mp = "mp"  # Madhya Pradesh
     mh = "mh"  # Maharashtra
     mn = "mn"  # Manipur
@@ -38,4 +40,11 @@ class StateCodeEnum(str, Enum):
     tr = "tr"  # Tripura
     up = "up"  # Uttar Pradesh
     uk = "uk"  # Uttarakhand
-    wb = "wb"  # West Bengal
\ No newline at end of file
+    wb = "wb"  # West Bengal
+    
+    # Union Territories
+    an = "an"  # Andaman and Nicobar Islands
+    ch = "ch"  # Chandigarh
+    dn = "dn"  # Dadra and Nagar Haveli and Daman and Diu
+    ld = "ld"  # Lakshadweep
+    py = "py"  # Puducherry
\ No newline at end of file
